@@ -183,6 +183,29 @@ class InflectorTest extends CakeTestCase {
 		$this->assertEquals(Inflector::singularize(''), '');
 	}
 
+/**
+ * Test that overlapping irregulars don't collide.
+ *
+ * @return void
+ */
+	public function testSingularizeMultiWordIrregular() {
+		Inflector::rules('singular', array(
+			'irregular' => array(
+				'preguntas_frecuentes' => 'pregunta_frecuente',
+				'categorias_preguntas_frecuentes' => 'categoria_pregunta_frecuente',
+			)
+		));
+		$this->assertEquals('pregunta_frecuente', Inflector::singularize('preguntas_frecuentes'));
+		$this->assertEquals(
+			'categoria_pregunta_frecuente',
+			Inflector::singularize('categorias_preguntas_frecuentes')
+		);
+		$this->assertEquals(
+			'faq_categoria_pregunta_frecuente',
+			Inflector::singularize('faq_categorias_preguntas_frecuentes')
+		);
+	}
+
 /**
  * testInflectingPlurals method
  *
@@ -256,6 +279,29 @@ class InflectorTest extends CakeTestCase {
 		$this->assertEquals(Inflector::pluralize(''), '');
 	}
 
+/**
+ * Test that overlapping irregulars don't collide.
+ *
+ * @return void
+ */
+	public function testPluralizeMultiWordIrregular() {
+		Inflector::rules('plural', array(
+			'irregular' => array(
+				'pregunta_frecuente' => 'preguntas_frecuentes',
+				'categoria_pregunta_frecuente' => 'categorias_preguntas_frecuentes',
+			)
+		));
+		$this->assertEquals('preguntas_frecuentes', Inflector::pluralize('pregunta_frecuente'));
+		$this->assertEquals(
+			'categorias_preguntas_frecuentes',
+			Inflector::pluralize('categoria_pregunta_frecuente')
+		);
+		$this->assertEquals(
+			'faq_categorias_preguntas_frecuentes',
+			Inflector::pluralize('faq_categoria_pregunta_frecuente')
+		);
+	}
+
 /**
  * testInflectingMultiWordIrregulars
  *
@@ -414,6 +460,19 @@ class InflectorTest extends CakeTestCase {
 		$this->assertSame(Inflector::underscore(false), '');
 	}
 
+/**
+ * Test camelize()
+ *
+ * @return void
+ */
+	public function testCamelize() {
+		$this->assertSame('BlogArticles', Inflector::camelize('blog_articles'));
+		$this->assertSame('BlogArticles', Inflector::camelize('blog articles'));
+		$this->assertSame('MyPlugin.MyClass', Inflector::camelize('MyPlugin.MyClass'));
+		$this->assertSame('MyPlugin.MyClass', Inflector::camelize('my_plugin.MyClass'));
+		$this->assertSame('MyPlugin.myClass', Inflector::camelize('MyPlugin.my_class'));
+	}
+
 /**
  * testVariableNaming method
  *
@@ -444,10 +503,10 @@ class InflectorTest extends CakeTestCase {
  * @return void
  */
 	public function testTableNaming() {
-		$this->assertEquals(Inflector::tableize('ArtistsGenre'), 'artists_genres');
-		$this->assertEquals(Inflector::tableize('FileSystem'), 'file_systems');
-		$this->assertEquals(Inflector::tableize('News'), 'news');
-		$this->assertEquals(Inflector::tableize('Bureau'), 'bureaus');
+		$this->assertEquals('artists_genres', Inflector::tableize('ArtistsGenre'));
+		$this->assertEquals('file_systems', Inflector::tableize('FileSystem'));
+		$this->assertEquals('news', Inflector::tableize('News'));
+		$this->assertEquals('bureaus', Inflector::tableize('Bureau'));
 	}
 
 /**
@@ -456,11 +515,12 @@ class InflectorTest extends CakeTestCase {
  * @return void
  */
 	public function testHumanization() {
-		$this->assertEquals(Inflector::humanize('posts'), 'Posts');
-		$this->assertEquals(Inflector::humanize('posts_tags'), 'Posts Tags');
-		$this->assertEquals(Inflector::humanize('file_systems'), 'File Systems');
-		$this->assertEquals(Inflector::humanize('hello_wörld'), 'Hello Wörld');
-		$this->assertEquals(Inflector::humanize('福岡_city'), '福岡 City');
+		$this->assertEquals('Posts', Inflector::humanize('posts'));
+		$this->assertEquals('Posts Tags', Inflector::humanize('posts_tags'));
+		$this->assertEquals('File Systems', Inflector::humanize('file_systems'));
+		$this->assertEquals('FiLe SysTems', Inflector::humanize('FiLe_SysTems'));
+		$this->assertEquals('Hello Wörld', Inflector::humanize('hello_wörld'));
+		$this->assertEquals('福岡 City', Inflector::humanize('福岡_city'));
 	}
 
 /**
